\name{00pcme-package}
\alias{pcme-package}
% \alias{pcme}
\docType{package}
\title{
  Maximum entropy for periodically correlated processes.
}
\description{
  This is an implementation of the method of Lambert-Lacroix and
  Boshnakov for maximum entropy completion of partially specified
  autocovariance functions of periodically correlated processes.
  % The method can be used for stationary multivariate time series, as well.
}
\details{
\tabular{ll}{
Package: \tab pcme\cr
Type: \tab Package\cr
Version: \tab 0.3 \cr
Date: \tab 2009-03-18\cr
License: \tab GPL (>= 2)\cr
LazyLoad: \tab yes\cr
}

A process \eqn{\{X_t\}}{(X_t)} is said to be periodically correlated of
period \eqn{T>1} (or simply \eqn{T}-periodically correlated) if for all
\eqn{k} and \eqn{l}
\deqn{Cov(X_{T+k},X_{T+k-l})=Cov(X_{k},X_{k-l}).}
Therefore the autocovariance function of \eqn{\{X_t\}}{(X_t)} can be
denoted by \eqn{R_k(l)=Cov(X_k,X_{k-l})}, where
\eqn{k=1,\ldots,T}{k=1,...,T} and \eqn{l=0,1,2,\ldots}{l=0,1,2,...}.  We
refer to \eqn{(k,l)} as a \emph{season-lag pair}, where \eqn{k} is the
season and \eqn{l} is the lag.

If a set of autocovariances is given and \eqn{l_{max}} is the maximal
lag of these autocovariances, then we can arrange them in a
\eqn{T\times(l_{max}+1)}{T x (lmax+1)} matrix \eqn{R} such that
\eqn{R_k(l)} occupies the \eqn{(k,l+1)}th entry of \eqn{R}:
\tabular{ccccc}{
    \eqn{R_{1}(0)}{R_1(0)}      \tab
    \eqn{R_{1}(1)}{R_1(1)}      \tab
    \eqn{R_{1}(2)}{R_1(2)}      \tab
    \ldots                      \tab
    \eqn{R_{1}(l_{max})}{R_1(lmax)} \cr
    \eqn{R_{2}(0)}{R_2(0)}      \tab
    \eqn{R_{2}(1)}{R_2(1)}      \tab
    \eqn{R_{2}(2)}{R_2(2)}      \tab
    \ldots                      \tab
    \eqn{R_{2}(l_{max})}{R_2(lmax)}      \cr
    \vdots                      \tab
    \vdots                      \tab
    \vdots                      \tab
    \vdots                      \tab
    \vdots                      \cr
    \eqn{R_{T}(0)}{R_T(0)}      \tab
    \eqn{R_{T}(1)}{R_T(1)}      \tab
    \eqn{R_{T}(2)}{R_T(2)}      \tab
    \ldots                      \tab
    \eqn{R_{T}(l_{max})}{R_T(lmax)}
  }
  where some of the entries may be missing if the autocovariances are
  not given for every season-lag pair on
  \eqn{(1:T) \times (0:(l_{max}+1))}{1:T x 0:(lmax+1)}.


  The maximum entropy (ME) problem is to find a model whose entropy is
  maximal among all models whose autocovariances coincide with the given
  ones.

  If the autocovariances are given over a set of lags which is
  contiguous and satisfies an additional technical condition, then the
  solution of the maximum entropy (ME) problem can be computed with the
  periodic Levinson-Durbin algorithm, otherwise the problem is
  non-linear. In any case the solution is a periodic autoregression
  model of order, say, \eqn{p_1,\ldots,p_T}.
  A season-lag pair is called a \emph{gap} if \eqn{R_{k}(l)}{R_k(l)} is
  missing and \eqn{l \le p_k}. We single out these lags since the
  maximum entropy problem can be solved by filling the gaps with values
  that maximise the entropy over the PAR(\eqn{p_1,\ldots,p_T}) models,
  see Boshnakov and Lacroix (2009?) for details.

  The main function in this package is \code{\link{pcme}}. It solves the
  ME problem for arbitrary patterns of lags. It implements the method of
  Boshnakov and Lambert-Lacroix (2009?).  See the examples below and
  also the help page of \code{\link{pcme}} for examples of its use.

  Besides \code{pcme}, of independent interest to users may be the
  functions implementing the periodic Levinson-Durbin algorithm, in
  particular \code{\link{LD}} and \code{\link{pldinverse}} (but see also
  package \code{pear} by McLeod and Mehmet (2008) for this kind of
  functionality).

  \code{LD} and \code{pldinverse} work with periodic partial
  autocorrelations, \eqn{\beta_k(l)}{B_k(l)}.  They are arranged in a
  matrix in a way analogous to the arrangement of periodic
  autocovariances described above:

  \tabular{ccccc}{
    \eqn{\beta_{1}(0)}{\beta_1(0)}      \tab
    \eqn{\beta_{1}(1)}{\beta_1(1)}      \tab
    \eqn{\beta_{1}(2)}{\beta_1(2)}      \tab
    \ldots                      \tab
    \eqn{\beta_{1}(l_{max})}{\beta_1(lmax)} \cr
    \eqn{\beta_{2}(0)}{\beta_2(0)}      \tab
    \eqn{\beta_{2}(1)}{\beta_2(1)}      \tab
    \eqn{\beta_{2}(2)}{\beta_2(2)}      \tab
    \ldots                      \tab
    \eqn{\beta_{2}(l_{max})}{\beta_2(lmax)}      \cr
    \vdots                      \tab
    \vdots                      \tab
    \vdots                      \tab
    \vdots                      \tab
    \vdots                      \cr
    \eqn{\beta_{T}(0)}{\beta_T(0)}      \tab
    \eqn{\beta_{T}(1)}{\beta_T(1)}      \tab
    \eqn{\beta_{T}(2)}{\beta_T(2)}      \tab
    \ldots                      \tab
    \eqn{\beta_{T}(l_{max})}{\beta_T(lmax)}
  }
  Also, we use the convention (see Lacroix 2005) that
  \eqn{\beta_k(0)=R_k(0)}{B_t(l)=R_k(0)} for \eqn{k=1,\ldots,T}.  In
  this way the partial correlations completely determine the covariance
  structure of the process.

  Functions \code{\link{pcme.test1}} and \code{\link{pcme.testcombn}}
  solve a "truckload" of problems by treating subsets of a given
  autocovariance sequence as unknown.

  Example autocovariances are given in \code{\link{pcme.paperex}} and
  \code{\link{pcme.someex}}.

  The autocovariances needed for \code{pcme} may be theoretical or
  sample ones. This package does not provide functions  for computing
  sample autocovariances, use package \code{pear} (see McLeod and  Mehmet
  (2008)) and \code{partsm} (see L\'opez-de-Lacalle (2005)).
}

\author{Sophie Lambert-Lacroix and Georgi Boshnakov

Maintainer: Georgi Boshnakov <Georgi.Boshnakov@manchester.ac.uk>
}
\references{
  Boshnakov, Georgi  and Lambert-Lacroix, Sophie (2009?)
  Maximum entropy for periodically correlated processes from
  nonconsecutive autocovariance coefficients.
  \emph{J. Time Series Anal.} (to appear)

  Lambert-Lacroix, Sophie (2005) Extension of autocovariance
  coefficients sequence for periodically correlated processes.
  \emph{Journal of Time Series Analysis}, \bold{26}, No. 6, 423-435.

  Lopez-de-Lacalle, Javier (2005). partsm: Periodic Autoregressive Time
  Series Models. R package version 1.0.

  McLeod, A. I.  and Balcilar, Mehmet. (2008). pear: Package for Periodic
  Autoregression Analysis. R package version 1.0.
  http://www.r-project.org

}
% ~~ Optionally other standard keywords, one per line, from file KEYWORDS in ~~
% ~~ the R documentation directory ~~
\keyword{ package }
\keyword{ ts }
\keyword{ optimize }
\seealso{
% ~~ Optional links to other man pages, e.g. ~~
% ~~ \code{\link[<pkg>:<pkg>-package]{<pkg>}} ~~
    \code{\link{pcme}}
}
\examples{
}
