\name{pcme}
\alias{pcme}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{ Find  the maximum entropy completion of a partially specified
  periodic autocovariance sequence }
\description{
  Find  the maximum entropy completion of a partially specified
  periodic autocovariance sequence or report that it does not exist.
}
\usage{
pcme(r, tau, x0 = NULL, method = "stabilNewton", gradient = TRUE,
     hessian = FALSE, autoshrink = TRUE, ...)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{r}{ the  autocovariances, see Details. }
  \item{tau}{ status of the  autocovariances, see Details. }
  \item{x0}{ initial values, see Details. }
  \item{method}{method to use, one of "nlm" and "stabilNewton".}
  \item{gradient}{ logical, if TRUE use analytical gradient }
  \item{hessian}{ logical, if TRUE use analytical Hessian }
  \item{\dots}{ other  arguments to  be passed to the optimisation
    functions. }
  \item{autoshrink}{if TRUE automaticallly reduce the number of
    parameters for non-linear optimisation, see Details.}
}
\details{
  The maximum entropy (ME) problem is solved by the method of Boshnakov
  and Lambert-Lacroix described in the reference below.
  % The gaps are filled initially with arbitrary values (actually zeroes)
  % or with \code{x0} (if given). If the resulting sequence is not
  % positive definite it is modified by adding a sufficiently large number
  % to the lag zero autocovariances. The modified ME problem is solved and
  % the obtained values of the gaps are tried for the original
  % problem. The process is repeated until the solution of a modified
  % problem gives an admissible solution to the original problem.
  A sequence of ME problems is solved until an admissible initial value
  is found. This sequence is finite and usually no longer than 2. Then
  one final maximisation solves the original problem. So, the initial
  value is not a problem. For other properties properties of the method
  and how it detects the absense of solutions or that they are only
  non-negative definite see the referenced paper.

  The argument \code{x0} is not really necessary as
  our method efficiently finds a valid initial value. When the
  the ME problem has no solution, there is no valid initial value and
  this is also reported by the method.

  By default the non-linear maximization for the modified ME problems is
  done with a stable hybrid Newton method implemented in this package
  (see \code{\stabilNewton}), use argument \code{method="nlm"} to switch
  to the core \R function \code{nlm}. The results are usually comparable
  but in certain circumstances \code{nlm} may fail, while in our
  experience the stable version is virtually indestructible.  Note that
  the function \code{stableNewton} is specifically tailored to this
  problem and is overly conservative with the convergence criteria.

  When \code{method="nlm"}, \code{nlm} may decide that the analytical
  derivatives are wrong and ignore them, use the relevant argument of
  \code{nlm} if you wish to prevent this. This usually happens when the
  autocovariances are close to the boundary of the admissible region
  since the derivatives may well go bezerk without being wrong. In such
  cases \code{nlm} sometimes fails while the stable method always
  succeeds.  It is essential to keep the parameters within the
  admissible region during optimisation and this is sometimes difficult
  with \code{nlm}.

  If \code{autoshrink} is TRUE determine the order of the ME model in
  advance  and optimise with respect to gaps within this order,
  see Boshnakov and Lacroix (2009?) for more information. The acf for
  the remaining missing values are then obtained from the periodic
  Yule-Walker equations.
  If \code{autoshrink} is not TRUE the order of all seasons is set to
  \code{ncol(r)-1}. The the methods give the same values for the missing
  autocovariances but the non-linear optimisation in the second one is
  in larger dimension. Also, the model fitted with
  \code{autoshrink=TRUE} is the "true" one, the excessive coefficients
  in the second method are theoretically zero but numerically only close
  to zero.


  Arguments \code{gradient} and \code{hessian} are ignored by
  \code{stabilNewton}, when it is used.
}
\value{
  a list with the following components:
  \item{entropy  }{value of the entropy at thesolution}
  \item{Rg       }{autocovariances at the gaps}
  % \item{minimum  }{NULL}
  % \item{estimate }{NULL}
  \item{gaps }{the gaps as season-lag pairs}
  \item{enthist }{entropyhistory }
  \item{nf }{nf}
  \item{ck }{list of ck's}
  \item{totaloptimhistory }{}
  \item{x0 }{initial value}
}
\references{
  Boshnakov, Georgi  and Lambert-Lacroix, Sophie (2009?)
  Maximum entropy for periodically correlated processes from
  nonconsecutive autocovariance coefficients.
  \emph{J. Time Series Anal.} (to appear)
}
\author{ Georgi Boshnakov }
%\note{ }
% \seealso{
%   ~~objects to See Also as \code{\link{help}}, ~~~
% }
\examples{
data(pcme.paperex)
attach(pcme.paperex)  # make rex1 directly visible

gap1p2 <- list(c(1,2))  # define some gaps
gap2p2 <- list(c(2,2))

# internally use this package's modified Newton method
resex1a <- pcme(rex1,gap1p2)
resex2a <- pcme(rex2,gap1p2)
resex3a <- pcme(rex3,gap1p2)
resex4a <- pcme(rex4,gap1p2)
resex5a <- pcme(rex5,gap2p2)


# internally use core R function "nlm"

### with nlm, without analytical derivatives
resex1 <- pcme(rex1,gap1p2,method="nlm",gradient=FALSE)
resex2 <- pcme(rex2,gap1p2,method="nlm",gradient=FALSE)
resex3 <- pcme(rex3,gap1p2,method="nlm",gradient=FALSE)
resex4 <- pcme(rex4,gap1p2,method="nlm",hessian=TRUE,check.analyticals=FALSE)
resex5 <- pcme(rex5,gap2p2,method="nlm",hessian=TRUE,check.analyticals=FALSE)

### With analytical Hessian

resex1h <- pcme(rex1,gap1p2,method="nlm",hessian=TRUE,check.analyticals=FALSE)
resex2h <- pcme(rex2,gap1p2,method="nlm",hessian=TRUE,check.analyticals=FALSE)
resex3h <- pcme(rex3,gap1p2,method="nlm",hessian=TRUE,check.analyticals=FALSE)
resex4h <- pcme(rex4,gap1p2,method="nlm",hessian=TRUE,check.analyticals=FALSE)
resex5h <- pcme(rex5,gap2p2,method="nlm",hessian=TRUE,check.analyticals=FALSE)

}
% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.
\keyword{ ts }
