\name{workhorse}
\alias{workhorse}
\alias{f.pcentropy}
\title{ Prepare a maximum entropy task }
\description{
  Prepare a closure for the maximum entropy task at hand.
  This is a relatively low-level function.
}
\usage{
f.pcentropy(r, tau, method, autoshrink = TRUE)
}
\arguments{
  \item{r}{ a numeric matrix of autocovariances, see Details.}
  \item{tau}{ a numeric matrix of the same size as \code{r} or a list of
    season-lag pairs. Indicates the missingness status of
    autocovariances, see Details. }
  \item{method}{ "nlm" or "stabilNewton", indicate method for numerical
    optimisation, see Details. }
  \item{autoshrink}{if TRUE automaticallly reduce the number of
    parameters for non-linear optimisation, see Details.}
}
\details{
  This is a relatively low-level function.
  For normal use \code{\link{pcme}} should suffice.

  \code{r} is a matrix with \eqn{T} rows such that \code{r[k,l]} is
  equal to \eqn{R_k(l-1)} but  the value \code{r[k,l]=NA} designates the
  season-lag pair \eqn{(k,l)} as missing.

  \code{tau} is a matrix having the same size as \code{r}
  indicating the status of each element of \code{r}:
  \code{tau[k,l+1] = 1} if \eqn{R_k(l)} is given,
  \code{tau[k,l+1] = 0} if \eqn{R_k(l)} corresponds to a gap, and
  \code{tau[k,l+1] = 2} if \eqn{R_k(l)} is missing but \eqn{(k,l)} is not
  a gap. \code{tau} may be set to 0 for all missing season-lag pairs. By
  default the types of the missing values (gaps or not gaps) are
  determined automatically, see argument \code{autoshrink} which controls
  this.

  \code{tau} may also be a list. Each element of this list is a
  season-lag pair specifying a missing value.

  If \code{method} is "nlm", then the core R function \code{nlm} is used
  for non-linear optimisation, otherwise an implementation of the
  modified Newton method provided by this package is used.

  If \code{autoshrink} is TRUE, then determine the order of the ME model
  in advance, classify the missing season-lag pairs as gaps or not gaps,
  and optimise with respect to the gaps, see Boshnakov and
  Lacroix (2009?) for more information. The acf values for the remaining
  missing values are then obtained from the periodic Yule-Walker
  equations.

  If \code{autoshrink} is not TRUE the order of all seasons is set to
  \code{ncol(r)-1}. The two methods give the same values (numerically)
  for the missing autocovariances but the non-linear optimisation in the
  second one is in larger dimension. Also, the model fitted with
  \code{autoshrink=TRUE} is the "true" one, the excessive coefficients
  in the second method are theoretically zero but numerically only close
  to zero.

  The list returned by \code{f.pcentropy} contains functions of several
  types.

  \code{mesolve} is the function to call to solve the ME problem. It can
  be called without arguments. Argument \code{xinit} is effectively
  redundant as \code{mesolve} has a very efficient way of locating
  initial condition. \code{xinit} was used for testing the behaviour of
  the algorithm with extremely weird initial conditions. If \code{xinit}
  is a scalar (usually 0), then all gaps are filled initially with this
  scalar. In fact, \code{f.pcentropy} initialises the gaps with whatever
  value were found in the corresponding places in the autocovariance
  function (??? does it deal with NA's?). Since the autocovariances have
  two indices, it is important when giving initial values to put them in
  the vector in the same order as \code{mesolve} expects. If the length
  of \code{xinit} is greater than 1 and does not match the number of
  gaps, it is ignored. In short, specifying \code{xinit} is hardly
  needed but cannot do any harm.

  \code{f,fg,fgh} implement the periodic Levinson-Durbin algorithm and
  its extension to calculate the entropy, its gradient and Hessian.
  \code{f} calculates entropy only,
  \code{fg} entropy and gradient, and
  \code{fgh} all three. The value returned by these functions is a
  scalar (the entropy) with attributtes "gradient" and "hessian" for the
  derivatives.

  \code{x0} is an initial value and is normally omitted for the ME
  problem.

  \code{pdq} tests if the current autocovariances are p.d. completable.
  \code{makepdq} makes sure that this is so by adding a sufficiently
  large constant to the lag zero autocovariances.

  \code{ftau} and \code{ftaufull} give the matrix \code{tau} describing
  the missingness of season-lag pairs. \code{ftaufull} is the one
  obtained after interpreting the input arguments, \code{ftau} is the
  one actually used for optimisation. \code{ftau} may have fewer columns
  if \code{autoshrink=TRUE}.

  \code{findexgaps} and \code{ffreelags} give the gaps and the non-gaps
  missing season-lag pairs as two column matrices with each row
  containing the position of a season-lag pair in \code{ftau} (so the
  corresponding lags are obtained by subtracting 1 from the second
  column). (??? check this description!)

  After a run of \code{mesolve}, \code{fent} contains the entropy at the
  optimal point.

  \code{p} is the model order.

  \code{fnf}, \code{fckvec}, and \code{totalhistory} contin information
  about the running of the algorithm.
  (??? Add argument to suppress output and storage of this information.)


}
\value{
  The function creates a closure for the maximum entropy task and
  returns a list whose elements give the user access to the relevant
  parts of this closure.
  \item{mesolve }{function that solves the ME problem. }
  \item{f}{ the function being optimised. }
  \item{fg }{ the function being optimised and its gradient. }
  \item{fgh }{ the function being optimised, its gradient, and Hessian. }
  \item{x0 }{ function that returns the initial value }
  \item{pdq }{function to check if an acf sequence is positive definite. }
  \item{makepd}{function that makes an acf positive definite. }
  \item{ftau }{ a matrix describing the gaps.}
  \item{ftaufull }{ a matrix describing the gaps.}
  \item{findexgaps}{???}
  \item{ffreelags}{???}
  \item{fent }{ a function returning the a history of the entropy
    during the optimisation process.}
  \item{p}{model order}
  \item{fnf }{ function returning the number of evaluations of \code{f}.}
  \item{fckvec }{ ??? }
  \item{totalhistoty}{function returning comprehensive history of the calculation. }
}
\references{
  Boshnakov, Georgi  and Lambert-Lacroix, Sophie (2009?)
  Maximum entropy for periodically correlated processes from
  nonconsecutive autocovariance coefficients.
  \emph{J. Time Series Anal.} (to appear)

  Lambert-Lacroix, Sophie (2005) Extension of autocovariance
  coefficients sequence for periodically correlated processes.
  \emph{Journal of Time Series Analysis}, \bold{26}, No. 6, 423-435.
}
\author{ Georgi Boshnakov }
%\note{}
\seealso{ \code{\link{pcme}} }
\examples{
}
% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.
% \keyword{ ~kwd1 }
